/*
 * To change this license header, choose License Headers in Project Properties.
 * To change this template file, choose Tools | Templates
 * and open the template in the editor.
 */
package sikd.ikonsol.ejb.session;

import java.util.List;
import javax.ejb.Remote;
import sikd.ikonsol.model.TrialBalance;

/**
 *
 * @author riyan
 */
@Remote
public interface TrialBalanceEjbHome {
    public List<TrialBalance> findAll();

    public TrialBalance findByID(int id);
 
    public List<TrialBalance> findAllByTahunKode(int tahun,String kodePemda,int idbas, String kodePeriode);
    
    public List<TrialBalance> findEksportByTahunKode(int tahun,String kodePemda,int idbas, String kodePeriode);

        public List<TrialBalance> findAllByTahunKode2(String kdrek1,int tahun,String kodePemda,int idbas, String kodePeriode);

           public List<TrialBalance> findAllByTahunKode3(String kdrek1,String kdrek2,int tahun,String kodePemda,int idbas, String kodePeriode);

                  public List<TrialBalance> findAllByTahunKode4(String kdrek1,String kdrek2,
                          String kdrek3,int tahun,String kodePemda,int idbas, String kodePeriode);

        
    public List<TrialBalance> findAllByTahunKodeDetail(String kdrek1,
            String kdrek2,String kdrek3,int tahun,String kodePemda,int idbas, String kodePeriode);



    public List<TrialBalance> findAllByTahunKodeSum(int tahun,String kodePemda,int idbas, String kodePeriode);
    
}
